==> bloodhound_7.5.1.orig.tar.gz: BloodHound-7.5.1/packages/javascript/bh-shared-ui/src/hooks/index.ts <==
// Copyright 2023 Specter Ops, Inc.
//
// Licensed under the Apache License, Version 2.0
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// SPDX-License-Identifier: Apache-2.0

export { default as useOnClickOutside } from './useOnClickOutside';

export { default as useDebouncedValue } from './useDebouncedValue';

export { default as useToggle } from './useToggle';

export { default as useApiVersion } from './useApiVersion';

export * from './useAvailableEnvironments';

export * from './useConfiguration';

export * from './useDataQualityStats';

export * from './useFeatureFlags';

export * from './useFetchEntityProperties';

export * from './useFileIngest';

export * from './useGraphItem';

export * from './useMountEffect';

export * from './usePermissions';

export * from './useSavedQueries';

export * from './useSearch';

export * from './useExploreParams';

export * from './useExploreGraph';

export * from './useExploreSelectedItem';

export * from './useEnvironmentParams';

export * from './useShowNavBar';

export * from './useIsMouseDragging';

export * from './useMatchingPaths';

export * from './useInitialEnvironment';

export * from './usePreviousValue';

export * from './useCustomNodeKinds';

export * from './useGraphHasData';

==> bloodhound_8.0.2.orig.tar.gz: BloodHound-8.0.2/packages/javascript/bh-shared-ui/src/hooks/index.ts <==
// Copyright 2023 Specter Ops, Inc.
//
// Licensed under the Apache License, Version 2.0
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// SPDX-License-Identifier: Apache-2.0

export { default as useOnClickOutside } from './useOnClickOutside';

export { default as useDebouncedValue } from './useDebouncedValue';

export { default as useToggle } from './useToggle';

export { default as useApiVersion } from './useApiVersion';

export { default as useCreateDisableZoomRef } from './useCreateDisableZoomRef';

export * from './useAssetGroupTags';

export * from './useAvailableEnvironments';

export * from './useConfiguration';

export * from './useDataQualityStats';

export * from './useFeatureFlags';

export * from './useFetchEntityProperties';

export * from './useFileIngest';

export * from './useGraphItem';

export * from './useMountEffect';

export * from './usePermissions';

export * from './useSavedQueries';

export * from './useSearch';

export * from './useExploreParams';

export * from './useExploreGraph';

export * from './useExploreSelectedItem';

export * from './useEnvironmentParams';

export * from './useShowNavBar';

export * from './useIsMouseDragging';

export * from './useMatchingPaths';

export * from './useInitialEnvironment';

export * from './usePreviousValue';

export * from './useCustomNodeKinds';

export * from './useExploreTableAutoDisplay';

export * from './useGraphHasData';

export * from './useSelectedTagName';

export * from './useZoneParams';
